@@ -90,7 +90,7 @@
 
 static char *input_filename, data_filename[MAXPATHLEN];
 
-static FILE *Inf, *Dataf, *Outf;
+static FILE *Inf, *Dataf;
 
 static off_t pos, Seekpts[2]; /* seek pointers to fortunes */
 
@@ -106,6 +106,7 @@ static void getargs(char *argv[])
         input_fn_2_data_fn();
     }
     else
+    {
         /*    {
          * Don't write out errors here, either; trust in exit codes and sh
          * fprintf(stderr, "No input file name\n");
@@ -113,7 +114,8 @@ static void getargs(char *argv[])
          * [outputfile]\n");
          */
         exit(1);
-    /*    } */
+        /*    } */
+    }
 }
 
 /*
@@ -125,7 +127,9 @@ static void get_pos(STRFILE *fp)
 {
     pos = random() % fp->str_numstr;
     if (++(pos) >= (off_t)(fp->str_numstr))
+    {
         pos -= fp->str_numstr;
+    }
 }
 
 /*
@@ -135,33 +139,38 @@ static void get_pos(STRFILE *fp)
 static void get_fort(STRFILE fp)
 {
     get_pos(&fp);
-    fseek(Dataf, (long)(sizeof fp + pos * sizeof Seekpts[0]), SEEK_SET);
+    fseek(Dataf, (long)((long)sizeof(fp) + pos * (long)sizeof(Seekpts[0])),
+        SEEK_SET);
     if (!fread(Seekpts, sizeof Seekpts, 1, Dataf))
     {
         exit(1);
     }
-    Seekpts[0] = ntohl(Seekpts[0]);
-    Seekpts[1] = ntohl(Seekpts[1]);
+    Seekpts[0] = ntohl((uint32_t)Seekpts[0]);
+    Seekpts[1] = ntohl((uint32_t)Seekpts[1]);
 }
 
 static void display(FILE *fp, STRFILE table)
 {
-    char *p, ch;
     char line[BUFSIZ];
-    int i;
 
     fseek(fp, (long)Seekpts[0], SEEK_SET);
-    for (i = 0; fgets(line, sizeof line, fp) && !STR_ENDSTRING(line, table);
-         i++)
+    for (; fgets(line, sizeof line, fp) && !STR_ENDSTRING(line, table);)
     {
         if (table.str_flags & STR_ROTATED)
-            for (p = line; (ch = *p); ++p)
+        {
+            char ch;
+            for (char *p = line; (ch = *p); ++p)
             {
                 if (isupper(ch))
+                {
                     *p = 'A' + (ch - 'A' + 13) % 26;
+                }
                 else if (islower(ch))
+                {
                     *p = 'a' + (ch - 'a' + 13) % 26;
+                }
             }
+        }
         fputs(line, stdout);
     }
     fflush(stdout);
@@ -196,10 +205,8 @@ int main(int argc GCC_UNUSED, char **argv)
     get_fort(tbl);
     display(Inf, tbl);
 
-    exit(0);
-
     fclose(Inf);
     fclose(Dataf);
-    fclose(Outf);
-    exit(0);
+
+    return 0;
 }
